# Explainer

The `Explainer` class is part of the `jarvais.explainer` module. It generates explainability reports for trained models.

::: jarvais.explainer.Explainer
    options:
        heading_level: 3
        members_order: source
        show_root_heading: true

---

The `BiasExplainer` class is used by the `Explainer` class to run a bias audit.

::: jarvais.explainer.BiasExplainer
    options:
        heading_level: 3
        members_order: source
        show_root_heading: true